@@ -16,7 +16,19 @@ CECSuit=function(value,crop="wheat"){
   else if(crop=="lentil"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
   else if(crop=="soybean"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
 
-  #Soil CEC (Cmol/kg) suitability classes for oilcrops
+  #Soil CEC (Cmol/kg) suitability classes for Forests
+  else if(crop=="poplar"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="grevillea"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="sesbania"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="calliandra"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="leucaena"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="acacia"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="eucalyptus"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="teak"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="maple"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+  else if(crop=="ash"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
+
+    #Soil CEC (Cmol/kg) suitability classes for oilcrops
   else if(crop=="sesame"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
   else if(crop=="sunflower"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
   else if(crop=="oilpalm"){suitclass=ifelse(value>24,1,ifelse(value>16,2,ifelse(value>8,3,4)))}
